/*
	Need to verify it works properly - if not, transfer the ammo on weapon pickup instead.
*/

#pragma semicolon 1
#define PLUGIN_VERSION "1.0.0"
#include <sourcemod>
//#include <sdkhooks>
//#include <sdktools>

#pragma newdecls required

ArrayList g_asPrimaryWeapons;
ArrayList g_asSecondaryWeapons;

public Plugin myinfo =
{
	name = "TOG Danger Zone Weapon Clips",
	author = "That One Guy",
	description = "Moves ammo from reserve to the gun clip for all weapons spawned",
	version = PLUGIN_VERSION,
	url = "https://www.togcoding.com/togcoding/"
}

public void OnPluginStart()
{
	CreateConVar("togdzwc_version", PLUGIN_VERSION, "TOG Danger Zone Weapon Clips - version number.", FCVAR_NOTIFY|FCVAR_DONTRECORD);
	
	g_asPrimaryWeapons = new ArrayList(64);
	g_asSecondaryWeapons = new ArrayList(64);
	SetLists();
}

void SetLists()
{
	g_asPrimaryWeapons.Clear();
	g_asSecondaryWeapons.Clear();
	
	g_asPrimaryWeapons.PushString("weapon_g3sg1");
	g_asPrimaryWeapons.PushString("weapon_awp");
	g_asPrimaryWeapons.PushString("weapon_aug");
	g_asPrimaryWeapons.PushString("weapon_ak47");
	g_asPrimaryWeapons.PushString("weapon_m4a1_silencer");
	g_asPrimaryWeapons.PushString("weapon_galilar");
	g_asPrimaryWeapons.PushString("weapon_famas");
	g_asPrimaryWeapons.PushString("weapon_p90");
	g_asPrimaryWeapons.PushString("weapon_ump45");
	g_asPrimaryWeapons.PushString("weapon_mac10");
	g_asPrimaryWeapons.PushString("weapon_xm1014");
	g_asPrimaryWeapons.PushString("weapon_m249");
	g_asPrimaryWeapons.PushString("weapon_negev");
	g_asPrimaryWeapons.PushString("weapon_scar20");
	g_asPrimaryWeapons.PushString("weapon_sawedoff");
	g_asPrimaryWeapons.PushString("weapon_mag7");
	g_asPrimaryWeapons.PushString("weapon_nova");
	g_asPrimaryWeapons.PushString("weapon_ssg08");
	g_asPrimaryWeapons.PushString("weapon_sg556");
	g_asPrimaryWeapons.PushString("weapon_mp9");
	g_asPrimaryWeapons.PushString("weapon_mp7");
	g_asPrimaryWeapons.PushString("weapon_bizon");
	g_asPrimaryWeapons.PushString("weapon_m4a4");
	//Possible non-existing weapons... (one of the two mp5's should be real though)
	g_asPrimaryWeapons.PushString("weapon_m4a1");
	g_asPrimaryWeapons.PushString("weapon_mp5sd");
	g_asPrimaryWeapons.PushString("weapon_mp5navy");
	g_asPrimaryWeapons.PushString("weapon_m3");
	g_asPrimaryWeapons.PushString("weapon_sg550");
	g_asPrimaryWeapons.PushString("weapon_sg552");
	g_asPrimaryWeapons.PushString("weapon_galil");
	
	g_asSecondaryWeapons.PushString("weapon_elite");
	g_asSecondaryWeapons.PushString("weapon_fiveseven");
	g_asSecondaryWeapons.PushString("weapon_deagle");
	g_asSecondaryWeapons.PushString("weapon_usp_silencer");
	g_asSecondaryWeapons.PushString("weapon_glock");
	g_asSecondaryWeapons.PushString("weapon_cz75a");
	g_asSecondaryWeapons.PushString("weapon_hkp2000");
	g_asSecondaryWeapons.PushString("weapon_revolver");
	g_asSecondaryWeapons.PushString("weapon_p250");
	g_asSecondaryWeapons.PushString("weapon_tec9");
}

public void OnEntityCreated(int iEntity, const char[] sClassname)
{
	if(StrContains(sClassname, "weapon_") != -1)
	{
		char sClass[65];
		strcopy(sClass, sizeof(sClass), sClassname);
		if(IsGun(sClass))		//check against list of weapon names
		{
			CreateTimer(0.5, TimerCB_ReloadWeapon, EntIndexToEntRef(iEntity), TIMER_FLAG_NO_MAPCHANGE);
		}
	}
}

bool IsGun(char[] sClassName)
{
	if(g_asPrimaryWeapons.FindString(sClassName) != -1)
	{
		return true;
	}
	
	if(g_asSecondaryWeapons.FindString(sClassName) != -1)
	{
		return true;
	}
	
	return false;
}

public Action TimerCB_ReloadWeapon(Handle hTimer, any iEntRef)
{
	int iEnt = EntRefToEntIndex(iEntRef);
	if(iEnt != INVALID_ENT_REFERENCE)
	{
		if(IsValidEntity(iEnt) && IsValidEdict(iEnt))
		{
			int iAmmo = GetEntProp(iEnt, Prop_Send, "m_iPrimaryReserveAmmoCount");
			SetEntProp(iEnt, Prop_Send, "m_iPrimaryReserveAmmoCount", 0);
			SetEntProp(iEnt, Prop_Send, "m_iClip1", iAmmo);
		}
	}
}

stock void Log(char[] sPath, const char[] sMsg, any ...)		//TOG logging function - path is relative to logs folder.
{
	char sLogFilePath[PLATFORM_MAX_PATH], sFormattedMsg[1500];
	BuildPath(Path_SM, sLogFilePath, sizeof(sLogFilePath), "logs/%s", sPath);
	VFormat(sFormattedMsg, sizeof(sFormattedMsg), sMsg, 3);
	LogToFileEx(sLogFilePath, "%s", sFormattedMsg);
}

/////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////// CHANGE LOG //////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////
/*
	1.0.0
		* Initial creation.
		
*/